==> dmc-sdk-5.3.2.1-sources.jar: com/digiwin/dap/middleware/dmc/common/comm/RequestMessage.java <==
package com.digiwin.dap.middleware.dmc.common.comm;

import com.digiwin.dap.middleware.dmc.HttpMethod;
import com.digiwin.dap.middleware.dmc.internal.model.WebServiceRequest;
import org.apache.http.HttpEntity;

import java.net.URI;

/**
 * Represent HTTP requests sent to DMC.
 *
 * @author fobgochod
 * @since 3.1.0.0
 */
public class RequestMessage extends HttpMessage {

    /**
     * The original request provided by user
     */
    private final WebServiceRequest originalRequest;
    /**
     * The service endpoint to which this request should be sent
     */
    private URI endpoint;
    /**
     * The HTTP method to use when sending this request
     */
    private HttpMethod method = HttpMethod.GET;
    /**
     * the entity associated with this request
     */
    private HttpEntity httpEntity;
    /**
     * 是否白名单，白名单不需要传token
     */
    private boolean whitelist;
    /**
     * 非幂等API，在特殊状态码如502、503时，强制重试
     */
    private boolean forceRetry;

    public RequestMessage() {
        this(null);
    }

    public RequestMessage(WebServiceRequest originalRequest) {
        this.originalRequest = (originalRequest == null) ? WebServiceRequest.NOOP : originalRequest;
    }

    public URI getEndpoint() {
        return endpoint;
    }

    public void setEndpoint(URI endpoint) {
        this.endpoint = endpoint;
    }

    public HttpMethod getMethod() {
        return method;
    }

    public void setMethod(HttpMethod method) {
        this.method = method;
    }

    public HttpEntity getHttpEntity() {
        return httpEntity;
    }

    public void setHttpEntity(HttpEntity httpEntity) {
        this.httpEntity = httpEntity;
    }

    public boolean isWhitelist() {
        return whitelist;
    }

    public void setWhitelist(boolean whitelist) {
        this.whitelist = whitelist;
    }

    public boolean isForceRetry() {
        return forceRetry;
    }

    public void setForceRetry(boolean forceRetry) {
        this.forceRetry = forceRetry;
    }

    public WebServiceRequest getOriginalRequest() {
        return originalRequest;
    }
}

==> dmc-sdk-5.4.0.0-sources.jar: com/digiwin/dap/middleware/dmc/common/comm/RequestMessage.java <==
package com.digiwin.dap.middleware.dmc.common.comm;

import com.digiwin.dap.middleware.dmc.HttpMethod;
import com.digiwin.dap.middleware.dmc.internal.model.WebServiceRequest;
import org.apache.http.HttpEntity;

import java.net.URI;

/**
 * Represent HTTP requests sent to DMC.
 *
 * @author fobgochod
 * @since 3.1.0.0
 */
public class RequestMessage extends HttpMessage {

    /**
     * The original request provided by user
     */
    private final WebServiceRequest originalRequest;
    /**
     * The service endpoint to which this request should be sent
     */
    private URI endpoint;
    /**
     * The HTTP method to use when sending this request
     */
    private HttpMethod method = HttpMethod.GET;
    /**
     * the entity associated with this request
     */
    private HttpEntity httpEntity;
    /**
     * 是否白名单，白名单不需要传token
     */
    private boolean whitelist;
    /**
     * 非幂等API，在特殊状态码如502、503时，强制重试
     */
    private boolean forceRetry;
    /**
     * 仅系统账号可访问
     */
    private boolean onlySysAccountAccess;

    public RequestMessage() {
        this(null);
    }

    public RequestMessage(WebServiceRequest originalRequest) {
        this.originalRequest = (originalRequest == null) ? WebServiceRequest.NOOP : originalRequest;
    }

    public URI getEndpoint() {
        return endpoint;
    }

    public void setEndpoint(URI endpoint) {
        this.endpoint = endpoint;
    }

    public HttpMethod getMethod() {
        return method;
    }

    public void setMethod(HttpMethod method) {
        this.method = method;
    }

    public HttpEntity getHttpEntity() {
        return httpEntity;
    }

    public void setHttpEntity(HttpEntity httpEntity) {
        this.httpEntity = httpEntity;
    }

    public boolean isWhitelist() {
        return whitelist;
    }

    public void setWhitelist(boolean whitelist) {
        this.whitelist = whitelist;
    }

    public boolean isForceRetry() {
        return forceRetry;
    }

    public void setForceRetry(boolean forceRetry) {
        this.forceRetry = forceRetry;
    }

    public WebServiceRequest getOriginalRequest() {
        return originalRequest;
    }

    public boolean isOnlySysAccountAccess() {
        return onlySysAccountAccess;
    }

    public void setOnlySysAccountAccess(boolean onlySysAccountAccess) {
        this.onlySysAccountAccess = onlySysAccountAccess;
    }
}
